﻿using System;
using SpeedBrowser.Data;
using SpeedBrowser.Enums;
using SpeedBrowser.GUIConfiguration;
using SpeedBrowser.GUIControls;
using SpeedBrowser.Utils;
using SpeedBrowser.SpeedBrowser;
using MediaPortal.Configuration;
using MediaPortal.GUI.Library;
using MediaPortal.Profile;


namespace SpeedBrowser
{
    public class Class1 : GUIWindow, ISetupForm
    {

            public sealed class GUIWebBrowser : GUIWindow, ISetupForm
    {
        [SkinControlAttribute(2)] private GUIButtonControl btnBack = null;
        [SkinControlAttribute(3)] private GUIButtonControl btnForward = null;
        [SkinControlAttribute(4)] private GUIButtonControl btnRefresh = null;
        [SkinControlAttribute(5)] private GUIButtonControl btnStop = null;
        [SkinControlAttribute(6)] private GUIButtonControl btnHome = null;
        [SkinControlAttribute(7)] private GUIButtonControl btnFav = null;
        [SkinControlAttribute(8)] private GUIButtonControl btnUrl = null;

        #region Variables
        public const int SpeedBrowser = 5555;
        private static readonly Logger logger = Logger.GetInstance();
        private bool _initSuccess;
        #endregion

        #region Delegates
        private delegate void InitializeControlsDelegate();
        #endregion

        #region Fields
        public string LinkId { get; set; }
        #endregion

        }

         #region ISetupForm Members

        // Returns the name of the plugin which is shown in the plugin menu
        public string PluginName()
        {
            return "Speed Browser";
        }

        // Returns the description of the plugin is shown in the plugin menu
        public string Description()
        {
            return "A WebBrowser plugin";
        }

        // Returns the author of the plugin which is shown in the plugin menu
        public string Author()
        {
            return "Quarter";
        }

        // show the setup dialog
        public void ShowPlugin()
        {
            ConfigForm config = new ConfigForm();
            config.ShowDialog();
        }

        // Indicates whether plugin can be enabled/disabled
        public bool CanEnable()
        {
            return true;
        }

        // Indicates if plugin is enabled by default;
        public bool DefaultEnabled()
        {
            return true;
        }

        // indicates if a plugin has it's own setup screen
        public bool HasSetup()
        {
            return true;
        }

       public int GetWindowId()
        {
            return WindowSpeedBrowser;
        }


        /// <summary>
        /// If the plugin should have it's own button on the main menu of Mediaportal then it
        /// should return true to this method, otherwise if it should not be on home
        /// it should return false
        /// </summary>
        /// <param name="strButtonText">text the button should have</param>
        /// <param name="strButtonImage">image for the button, or empty for default</param>
        /// <param name="strButtonImageFocus">image for the button, or empty for default</param>
        /// <param name="strPictureImage">subpicture for the button or empty for none</param>
        /// <returns>true : plugin needs it's own button on home
        /// false : plugin does not need it's own button on home</returns>

        public bool GetHome(out string strButtonText, out string strButtonImage,
          out string strButtonImageFocus, out string strPictureImage)
        {
            strButtonText = PluginName();
            strButtonImage = String.Empty;
            strButtonImageFocus = String.Empty;
            strPictureImage = String.Empty;
            return true;
        }

        #endregion

        #region Constructor

        /// <summary>
        /// Initializes a new instance of the <see cref="GUISpeedBrowser"/> class.
        /// </summary>
        public Class1()
        {
            GetID = WindowSpeedBrowser;
        }

        #endregion

        
        #region Overrides
        protected override void OnClicked(int controlId, GUIControl control, MediaPortal.GUI.Library.Action.ActionType actionType)
        {
            if (control == btnBack)
            {
                GeckoBrowserManager.GoBack();
                logger.WriteLog("Triggered the \"Go Back\" button", LogLevel.Debug);
            }
            else if (control == btnForward)
            {
                SpeedBrowserManager.GoForward();
                logger.WriteLog("Triggered the \"Go Forward\" button", LogLevel.Debug);
            }
            else if (control == btnRefresh)
            {
                Form1.RefreshBrowser();
                logger.WriteLog("Triggered the \"Refresh\" button", LogLevel.Debug);
            }
            else if (control == btnStop)
            {
                SpeedBrowserManager.StopBrowser();
                logger.WriteLog("Triggered the \"Stop\" button", LogLevel.Debug);
            }
            else if (control == btnHome)
            {
                SpeedBrowserManager.GoHome();
                logger.WriteLog("Triggered the \"Home\" button", LogLevel.Debug);
            }
            else if (control == btnUrl)
            {
                InitializeControlsDelegate d = new InitializeControlsDelegate(ShowUrlDialog);
                GUIGraphicsContext.form.BeginInvoke(d);
                
            }

            base.OnClicked(controlId, control, actionType);
        }

        public void ShowUrlDialog()
        {
            logger.WriteLog("Triggered the \"Enter Url\" button", LogLevel.Debug);
            string link = String.Empty;
            SpeedBrowserManager.HideWebBrowser();


            bool confirmed = SpeedBrowserUtils.ShowKeyboard(ref link, true);
            if (confirmed)
            {
                SpeedBrowserUtils.SetProperty("#Speedbrowser.link", String.Empty);
                SpeedBrowserUtils.SetProperty("#Speedbrowser.link.zoom", String.Empty);
                SpeedBrowserUtils.SetProperty("#Speedbrowser.link.shorturl", String.Empty);
                SpeedBrowserManager.Navigate(link, SpeedBrowserManager.GetDefaultZoom());
            }
            GeckoBrowserManager.ShowWebBrowser();
        }

        public void ShowInputDialog(HtmlLinkNumber id)
        {
            logger.WriteLog("Entered a INPUT field of website", LogLevel.Debug);
            string text = String.Empty;
            SpeedBrowserManager.HideWebBrowser();


            bool confirmed = SpeedBrowserUtils.ShowKeyboard(ref text, true);
            if (confirmed)
            {
                SpeedBrowserManager.SetInputFieldText(id.Number, text);
            }
            SpeedBrowserManager.ShowWebBrowser();
        }

        /// <summary>
        /// Inits this instance.
        /// </summary>
        /// <returns></returns>
        public override bool Init()
        {
            GUIControlFactory.RegisterControl("webbrowser", typeof(WebBrowserControl));
            SpeedBrowserUtils.InitLog();
            bool success = Load(GUIGraphicsContext.Skin + @"\geckobrowser.xml");
            return success;
        }

        /// <summary>
        /// Called when [action].
        /// </summary>
        /// <param name="action">The action.</param>
        public override void OnAction(MediaPortal.GUI.Library.Action action)
        {
            if (SpeedBrowserManager.InitializationSuccess)
            {
                switch (action.wID)
                {
                    case Action.ActionType.REMOTE_1:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 1;
                                SpeedBrowserUtils.SetProperty("#geckobrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.REMOTE_2:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 2;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.REMOTE_3:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 3;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.REMOTE_4:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 4;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.REMOTE_5:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 5;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.REMOTE_6:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 6;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.REMOTE_7:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 7;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.REMOTE_8:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 8;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.REMOTE_9:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 9;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.REMOTE_0:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                LinkId += 0;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: " + LinkId);
                            }
                            break;
                        }
                    case Action.ActionType.ACTION_CONTEXT_MENU:
                        {
                            if (SpeedBrowserManager.MouselessBrowsing)
                            {
                                HtmlLinkNumber hln = null;
                                if (SpeedBrowserManager.GetLinkById(Convert.ToInt32(LinkId), out hln))
                                {
                                    switch (hln.Type)
                                    {
                                        case HtmlInputType.Link:
                                            SpeedBrowserManager.Navigate(hln.Link, SpeedBrowserManager.GetDefaultZoom());
                                            break;
                                        case HtmlInputType.Input:
                                            ShowInputDialog(hln);
                                            break;
                                        case HtmlInputType.Action:
                                            SpeedBrowserManager.Navigate("javascript:document.getElementById(\"" + hln.Id + "\").click()");
                                            break;
                                    }
                                }
                                LinkId = string.Empty;
                                SpeedBrowserUtils.SetProperty("#Speedbrowser.linkid", "Navigate to LinkID: -");
                            }
                            break;
                        }
                    case Action.ActionType.ACTION_PAGE_DOWN:
                        {
                            SpeedBrowserManager.ZoomOut(GeckoBrowserManager.ZoomStep);
                            break;
                        }
                    case Action.ActionType.ACTION_PAGE_UP:
                        {
                            SpeedBrowserManager.ZoomIn(SpeedoBrowserManager.ZoomStep);
                            break;
                        }
                    case Action.ActionType.ACTION_PREVIOUS_MENU:
                        {
                            GUIWindowManager.ShowPreviousWindow();
                            return;
                        }
                    case Action.ActionType.ACTION_MOVE_DOWN:
                        {
                            SpeedBrowserManager.ScrollDown(100);
                            break;
                        }
                    case Action.ActionType.ACTION_MOVE_UP:
                        {
                            SpeedBrowserManager.ScrollUp(100);
                            break;
                        }
                    case Action.ActionType.ACTION_MOVE_LEFT:
                        {
                            SpeedBrowserManager.ScrollLeft(100);
                            break;
                        }
                    case Action.ActionType.ACTION_MOVE_RIGHT:
                        {
                            SpeedBrowserManager.ScrollRight(100);
                            break;
                        }
                }
            }
            base.OnAction(action);
        }

        #endregion    
    
public  int WindowSpeedBrowser { get; set; }}
}
